Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(331)

Unified Diff: components/tracing/tracing_messages.h

Issue 1329273002: [tracing] Send smaps file desciptor to child process for tracing (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Rebase. Created 5 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « components/tracing/child_trace_message_filter.cc ('k') | content/browser/tracing/trace_message_filter.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: components/tracing/tracing_messages.h
diff --git a/components/tracing/tracing_messages.h b/components/tracing/tracing_messages.h
index cd5a2020dda597897478a543e9cba3d1047857de..8322fa962b49946f4cfd541659d07443009ccc5c 100644
--- a/components/tracing/tracing_messages.h
+++ b/components/tracing/tracing_messages.h
@@ -22,14 +22,20 @@
#define IPC_MESSAGE_START TracingMsgStart
IPC_STRUCT_TRAITS_BEGIN(base::trace_event::TraceLogStatus)
-IPC_STRUCT_TRAITS_MEMBER(event_capacity)
-IPC_STRUCT_TRAITS_MEMBER(event_count)
+ IPC_STRUCT_TRAITS_MEMBER(event_capacity)
+ IPC_STRUCT_TRAITS_MEMBER(event_count)
IPC_STRUCT_TRAITS_END()
+IPC_STRUCT_BEGIN(TracingMsg_MemoryTracingInfo)
+ IPC_STRUCT_MEMBER(uint64, tracing_process_id)
+ IPC_STRUCT_MEMBER(IPC::PlatformFileForTransit, smaps_fd)
+ IPC_STRUCT_MEMBER(IPC::PlatformFileForTransit, status_fd)
+IPC_STRUCT_END()
+
IPC_STRUCT_TRAITS_BEGIN(base::trace_event::MemoryDumpRequestArgs)
-IPC_STRUCT_TRAITS_MEMBER(dump_guid)
-IPC_STRUCT_TRAITS_MEMBER(dump_type)
-IPC_STRUCT_TRAITS_MEMBER(level_of_detail)
+ IPC_STRUCT_TRAITS_MEMBER(dump_guid)
+ IPC_STRUCT_TRAITS_MEMBER(dump_type)
+ IPC_STRUCT_TRAITS_MEMBER(level_of_detail)
IPC_STRUCT_TRAITS_END()
IPC_STRUCT_TRAITS_BEGIN(base::trace_event::MemoryDumpArgs)
@@ -44,10 +50,11 @@ IPC_ENUM_TRAITS_MAX_VALUE(
static_cast<int>(base::trace_event::MemoryDumpType::LAST))
// Sent to all child processes to enable trace event recording.
-IPC_MESSAGE_CONTROL3(TracingMsg_BeginTracing,
- std::string /* trace_config_str */,
- base::TraceTicks /* browser_time */,
- uint64 /* Tracing process id (hash of child id) */)
+IPC_MESSAGE_CONTROL3(
+ TracingMsg_BeginTracing,
+ std::string /* trace_config_str */,
+ base::TraceTicks /* browser_time */,
+ TracingMsg_MemoryTracingInfo /* child process' memory tracing info */)
// Sent to all child processes to disable trace event recording.
IPC_MESSAGE_CONTROL0(TracingMsg_EndTracing)
« no previous file with comments | « components/tracing/child_trace_message_filter.cc ('k') | content/browser/tracing/trace_message_filter.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698